PALM-meteo: palmmeteo.library.TriRegridder Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.library.TriRegridder Class Reference

## Public Member Functions
def | __init__ (self, clat, clon, ylat, xlon, buffer)
def | loader (self, obj)
def | regrid (self, data)

## Public Attributes
| lon_coef
| ndim
| npt
| slices
| ptmask
| bary
| simp

## Detailed Description

    Universal regridder which uses Delaunay triangulation and barycentric
    coordinate interpolation.

    Works on any grid - triangular, rectangular or unstructured. The only
    requirements are the arrays of latitude and longitude coordinates. The grid
    arrays may be organized as 1- or 2-dimensional.

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.library.TriRegridder.__init__ | ( |  | self,
|  |  | clat,
|  |  | clon,
|  |  | ylat,
|  |  | xlon,
|  |  | buffer
| ) |  |

## Member Function Documentation

## ◆ loader()

def palmmeteo.library.TriRegridder.loader | ( |  | self,
|  |  | obj
| ) |  |

    Prepares a slicing object which automatically adds selector indices
    for this regridder.

## ◆ regrid()

def palmmeteo.library.TriRegridder.regrid | ( |  | self,
|  |  | data
| ) |  |

    Regrid from point set selected using loader

## Member Data Documentation

## ◆ bary

palmmeteo.library.TriRegridder.bary

## ◆ lon_coef

palmmeteo.library.TriRegridder.lon_coef

## ◆ ndim

palmmeteo.library.TriRegridder.ndim

## ◆ npt

palmmeteo.library.TriRegridder.npt

## ◆ ptmask

palmmeteo.library.TriRegridder.ptmask

## ◆ simp

palmmeteo.library.TriRegridder.simp

## ◆ slices

palmmeteo.library.TriRegridder.slices

The documentation for this class was generated from the following file:

- palmmeteo/library.py